@@ -2,11 +2,15 @@ from __future__ import annotations
 from typing import List, Optional
 from pydantic import BaseModel
 
-from . import (
-    ListingImage, ProductionPartner, ShippingProfile,
-    Shop, Translation, User,
-    Price, Product
-)
+from .ListingImageModel import ListingImage 
+from .ProductionPartnerModel import ProductionPartner
+from .ShippingProfileModel import ShippingProfile
+from .ShopModel import Shop
+from .TranslationModel import Translation
+from .UserModel import User
+from .PriceModel import Price
+from .ProductModel import Product
+
 
 class Inventory(BaseModel):
     products: List[Product]
