@@ -1,7 +1,6 @@
 from dataclasses import dataclass
-from etsy_apiv3.models.ShopModel import Shop
-from etsy_apiv3.utils.APIV3 import EtsySession
-from etsy_apiv3.utils.Response import Response
+from ..models import Shop
+from ..utils import EtsySession, Response
 
 @dataclass
 class ShopResource:
