@@ -2,7 +2,7 @@ from typing import Optional
 from requests_oauthlib import OAuth2Session
 from async_oauthlib import OAuth2Session as AsyncOAuth2Session
 import requests
-from . import EtsyRequestException
+from .RequestException import EtsyRequestException
 
 class EtsySession:
     
